@@ -16,9 +16,16 @@ class BasicSettings():
         self.dir_rel_settings = "settings"
         self.dir_rel_model = "stat_dict"
         self.log_path = None
+        self.model_path = None
+        self.model_path_timed = None
         #
-        self.agent_settings = {"name": "agentname"}
-        self.env_settings = {"name": "envname"}
+        self.env = "envname"
+        self.agent = "agentname"
+        self.buffer = "buffername"
+        self.trainer = "trainername"
+        #
+        self.agent_settings = {}
+        self.env_settings = {}
         self.buffer_settings = {"buffer_size": 5000}
         self.trainer_settings = {}
         #
@@ -29,9 +36,8 @@ class BasicSettings():
         self.load_from_json_file(file_path)
         #
         # except from saving
-        self.except_list = ["dir_base", "dir_log", "dir_settings", "dir_model",
-               "log_path", "dir_rel_log", "dir_rel_settings", "dir_rel_model",
-               "except_list"]
+        self.except_list = ["dir_log", "dir_settings", "dir_model", "str_datetime",
+               "log_path", "model_path", "model_path_timed", "except_list"]
         #
 
     #
@@ -49,16 +55,23 @@ class BasicSettings():
         if not os.path.exists(self.dir_model): os.mkdir(self.dir_model)
         #
         # logger
-        str_datetime = time.strftime("%Y-%m-%d-%H-%M-%S")
-        if self.log_path is None: self.log_path = os.path.join(
-                self.dir_log, "log_%s_%s_%s.txt" % (self.agent_settings["name"],
-                self.env_settings["name"], str_datetime) )
+        self.str_datetime = time.strftime("%Y_%m_%d_%H_%M_%S")
+        log_file = "log_%s_%s_%s.txt" % (self.env, self.agent, self.str_datetime)  
+        if self.log_path is None:
+            self.log_path = os.path.join(self.dir_log, log_file)
         #
         self.logger = self.create_logger(self.log_path)
         print("settings checked")
         #
         self.logger.info(self.trans_info_to_dict())
-        # self.display()
+        #
+        # model_path
+        model_file = "model_%s_%s_eval.stat_dict" % (self.env, self.agent)
+        model_path_eval = os.path.join(self.dir_model, model_file)
+        if self.model_path is None:
+            self.model_path = model_path_eval
+        #
+        self.model_path_timed = model_path_eval.replace("eval", self.str_datetime)
         #
 
     def create_logger(self, log_path):
